Smart Bucket (sbkt)
====================

Bidirectional synchronization between local directory and s3 bucket.


.. image:: https://github.com/thebjorn/smart-bucket/actions/workflows/ci-cd.yml/badge.svg
   :target: https://github.com/thebjorn/smart-bucket/actions/workflows/ci-cd.yml


.. image:: https://codecov.io/gh/thebjorn/smart-bucket/branch/master/graph/badge.svg?token=rG43wgZ3aK
   :target: https://codecov.io/gh/thebjorn/smart-bucket


.. image:: https://pepy.tech/badge/smart-bucket
   :target: https://pepy.tech/project/smart-bucket
   :alt: Downloads

.. image:: https://readthedocs.org/projects/smart-bucket/badge/?version=latest
   :target: https://smart-bucket.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

TODO:
-----

- [ ] describe sync algorithm
- [ ] describe deletion problem
